**********
Connection
**********

.. module:: spotify

.. autoclass:: spotify.connection.Connection

.. autoclass:: ConnectionRule
    :no-inherited-members:

.. autoclass:: ConnectionState
    :no-inherited-members:

.. autoclass:: ConnectionType
    :no-inherited-members:
